pub struct SvgHandle { /* private fields */ }Expand description
Handle used to hold SVG data in memory.
You can create this from one of the read methods in
Loader.
Implementations
Sourceimpl SvgHandle
impl SvgHandle
Sourcepub fn has_element_with_id(&self, id: &str) -> Result<bool, RenderingError>
pub fn has_element_with_id(&self, id: &str) -> Result<bool, RenderingError>
Checks if the SVG has an element with the specified id.
Note that the id must be a plain fragment identifier like #foo, with
a leading # character.
The purpose of the Err() case in the return value is to indicate an
incorrectly-formatted id argument.
Sourcepub fn set_stylesheet(&mut self, css: &str) -> Result<(), LoadingError>
pub fn set_stylesheet(&mut self, css: &str) -> Result<(), LoadingError>
Sets a CSS stylesheet to use for an SVG document.
During the CSS cascade, the specified stylesheet will be used with a “User” origin.
Note that @import rules will not be resolved, except for data: URLs.